# 'Polemarch' documentation

# Welcome to Polemarch’s documentation!

Polemarch is a service for infrastructure orchestration based on ansible. Simple WEB gui for infrastructure orchestration using ansible playbooks.

You could find latest releases there. Also you could find source code in official repository.

Contact us on any questions or report bugs.

Contents:

- Installation
  - Install from PyPI
  - Quickstart
  - Backup
  - Update
  - Update to 0.2.x
  - Migrate
  - Create superuser
  - Change password
- Configuration manual
  - Introduction
  - Polemarch clustering overview
  - Main settings
  - Database settings
  - Cache settings
  - Locks settings
  - Rpc settings
  - Web settings
  - Production web settings
  - Installation of additional packages to Polemarch
- GUI workflow
  - Welcome to Polemarch GUI
  - Before you start
  - Projects
  - Module execution
  - Template
  - Periodic tasks
  - Inventory
  - Group
  - Host
  - Variables for inventory, group, host
  - Hooks
  - Users
- API
- How to participate
- VST Consulting contributor agreement
  - 1. Definitions
  - 2. Copyright Assignment, License and Waiver
  - 3. Patent License
  - 4. Your Representation and Warranties.
  - 5. Intellectual Property
  - Miscellaneous